==> haskell-persistent-mysql-2.13.1.5-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-6b3ZgvzvUfrA6oCYW7U5tb
key:                  persistent-mysql-2.13.1.5-6b3ZgvzvUfrA6oCYW7U5tb
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  fbabcf8a42d5dccd3cf0633ca6a95a10
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-6b3ZgvzvUfrA6oCYW7U5tb
depends:
    aeson-2.1.2.1-FurzwiqHIOZ8NUBnR3RWtD base-4.17.2.1
    blaze-builder-0.4.4-Ex2IiKzN8lmx2tekDbDoI bytestring-0.11.5.3
    conduit-1.3.6.1-E5Krv6RV3hBBPS0slvyYkr containers-0.6.7
    monad-logger-0.3.42-9wN21l2PI338h9NA8VK0Z1
    mysql-0.2.1-AQ6mKDMeauLDLihuc57kdS
    mysql-simple-0.4.9-FTAIIpMVx8S9K8f5Uezm7i
    persistent-2.14.5.1-3cWHiOJ5F2N5xPqfcKrao6
    resource-pool-0.2.3.2-Ce97ZEeGrzj5HsY77vKl7e
    resourcet-1.2.6-KSdJbGYyd3pAgG4RlfssrZ text-2.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-mysql-2.13.1.5-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-5pnRiVj7heyJE6Usz8kJ3E
key:                  persistent-mysql-2.13.1.5-5pnRiVj7heyJE6Usz8kJ3E
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  5fd19867756c7b7f9b8e7b169f28aa83
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-5pnRiVj7heyJE6Usz8kJ3E
depends:
    aeson-2.1.2.1-FurzwiqHIOZ8NUBnR3RWtD base-4.17.2.1
    blaze-builder-0.4.4-Ex2IiKzN8lmx2tekDbDoI bytestring-0.11.5.3
    conduit-1.3.6.1-E5Krv6RV3hBBPS0slvyYkr containers-0.6.7
    monad-logger-0.3.42-9wN21l2PI338h9NA8VK0Z1
    mysql-0.2.1-AQ6mKDMeauLDLihuc57kdS
    mysql-simple-0.4.9-FTAIIpMVx8S9K8f5Uezm7i
    persistent-2.14.5.2-1RDSwVfe5AMK8SJJ4K4zxo
    resource-pool-0.2.3.2-Ce97ZEeGrzj5HsY77vKl7e
    resourcet-1.2.6-KSdJbGYyd3pAgG4RlfssrZ text-2.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
